#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-2B9SDgCnnaG1WKp35TTzdY
key:                  ghcide-test-utils-1.9.0.0-2B9SDgCnnaG1WKp35TTzdY
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  c412ea815c41193c7dd8b1f54e7d642c
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-2B9SDgCnnaG1WKp35TTzdY
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-aWEq6cZZ289lIc6yxljo5 filepath-1.4.300.1
    ghcide-2.3.0.0-JSGU2hqwpKP2T9zGvf4q95
    hls-plugin-api-2.3.0.0-4CgmjbnqzKN1c7iCNmzWCS
    lens-5.3.5-JKPJsUIkx0YEZ4W3JntdKw
    lsp-test-0.16.0.0-JhAqJZHUBLa6rYOpJRvkVO
    lsp-types-2.0.2.0-FxqOKdDzvom3LxZERPn3Y4
    tasty-hunit-0.10.2-IyGMLJQ0P1qA3GfBVc1Boi text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

